@@ -1,4 +1,4 @@
-# Copyright (c) 2014 Santiago Barreda
+# Copyright (c) 2015 Santiago Barreda
 # All rights reserved.
 
 
@@ -10,3 +10,11 @@ errorbars = function(x, y, top, bottom = top, length = .2, add = TRUE, ...){
   }
 }
 
+
+errorbar = function(x, y, top, bottom = top, length = .2, add = TRUE, ...){
+  cl = match.call()
+  args = sapply (2:length(cl), function(x) cl[[x]])
+  names(args) = names(cl)[-1]
+  do.call (errorbars, args)
+}
+
