@@ -1,8 +1,9 @@
-# Copyright (c) 2014 Santiago Barreda
+# Copyright (c) 2015 Santiago Barreda
 # All rights reserved.
 
 
 xsampatoIPA = function (vowels, chart = FALSE, verify = FALSE){
+  oldpar = par()
   if (missing(vowels) | chart == TRUE){ 
     par (mfrow = c(1,2))
     IPA = ipainfo()[c(1,4,5)]
@@ -17,6 +18,7 @@ xsampatoIPA = function (vowels, chart = FALSE, verify = FALSE){
           col = 1+IPA[[2]]$rounded*3)
     axis (side = 1, at = c(1.15,2.15,3.15), c('Front','Mid','Back'))
     axis (side = 2, at = c(1,2,3,4), c('open','open-mid','close-mid','close'))
+	suppressWarnings (par (oldpar))
   }
   if (!missing(vowels)){ 
     IPA = ipainfo()[c(1,5)]
@@ -24,10 +26,13 @@ xsampatoIPA = function (vowels, chart = FALSE, verify = FALSE){
     for (i in 1:length(IPA[[2]]))
       if (sum(IPA[[2]][i] == vowels)>0) out[IPA[[2]][i] == vowels] = IPA[[1]][i]
     if (verify == TRUE){
-      par (mfrow = c(1,1))
+	  par (mfrow = c(1,1))
       plot (1:length(out), rep(1,length(out)), pch = out, ylab='',yaxt='n', xlab='Selection',cex = 2,xaxt = 'n')
 	  axis (side = 1, at  = 1:length(out))
+      suppressWarnings (par (oldpar))
     }
     return(out)
   }
+ 
 }
+
